@@ -61,7 +61,7 @@ class ExpressionVariableRefBase(ExpressionBase):
     __slots__ = "variable", "variable_trace"
 
     def __init__(self, variable, source_ref):
-        ExpressionBase.__init__(self, source_ref=source_ref)
+        ExpressionBase.__init__(self, source_ref)
 
         self.variable = variable
         self.variable_trace = None
@@ -221,6 +221,9 @@ Check '%s' on dictionary lowered to dictionary '%s'.""" % (
 
         return in_node, tags, message
 
+    def getExpressionDictInConstant(self, value):
+        return self.variable_trace.getDictInValue(value)
+
     def computeExpressionSetSubscript(
         self, set_node, subscript, value_node, trace_collection
     ):
@@ -384,10 +387,6 @@ class ExpressionVariableRef(ExpressionVariableRefBase):
             "owner": self.variable.getOwner().getCodeName(),
         }
 
-    @staticmethod
-    def isExpressionTempVariableRef():
-        return True
-
     @classmethod
     def fromXML(cls, provider, source_ref, **args):
         assert cls is ExpressionVariableRef, cls
@@ -601,6 +600,14 @@ Replaced read-only module attribute '__spec__' with module attribute reference."
 
         return None, None, None
 
+    def collectVariableAccesses(self, emit_read, emit_write):
+        emit_read(self.variable)
+
+    def hasShapeListExact(self):
+        return (
+            self.variable_trace is not None and self.variable_trace.hasShapeListExact()
+        )
+
     def hasShapeDictionaryExact(self):
         return (
             self.variable_trace is not None
@@ -618,6 +625,11 @@ Replaced read-only module attribute '__spec__' with module attribute reference."
             and self.variable_trace.hasShapeUnicodeExact()
         )
 
+    def hasShapeBoolExact(self):
+        return (
+            self.variable_trace is not None and self.variable_trace.hasShapeBoolExact()
+        )
+
     def getTruthValue(self):
         return self.variable_trace.getTruthValue()
 
@@ -694,6 +706,10 @@ class ExpressionTempVariableRef(
     def getDetails(self):
         return {"variable": self.variable}
 
+    @staticmethod
+    def isExpressionTempVariableRef():
+        return True
+
     @classmethod
     def fromXML(cls, provider, source_ref, **args):
         assert cls is ExpressionTempVariableRef, cls
@@ -787,10 +803,7 @@ class ExpressionTempVariableRef(
             ),
         )
 
-        outline_body.setChild(
-            "body",
-            makeStatementsSequenceFromStatements(*statements),
-        )
+        outline_body.setChildBody(makeStatementsSequenceFromStatements(*statements))
 
         return False, trace_collection.computedExpressionResultRaw(
             outline_body,
