@@ -858,7 +858,7 @@ class Plugins(object):
                 pre_modules[full_name] = cls._createTriggerLoadedModule(
                     module=module,
                     trigger_name=pre_module_load_trigger_name,
-                    code="\n\n".join(total_code),
+                    code="".join(total_code),
                     flags=total_flags,
                 )
                 pre_modules_reasons[full_name] = tuple(reasons)
@@ -874,7 +874,7 @@ class Plugins(object):
                 post_modules[full_name] = cls._createTriggerLoadedModule(
                     module=module,
                     trigger_name=post_module_load_trigger_name,
-                    code="\n\n".join(total_code),
+                    code="".join(total_code),
                     flags=total_flags,
                 )
                 post_modules_reasons[full_name] = reasons
