@@ -29,12 +29,17 @@ import os
 
 import nuitka.specs.BuiltinBytesOperationSpecs
 import nuitka.specs.BuiltinDictOperationSpecs
+import nuitka.specs.BuiltinListOperationSpecs
 import nuitka.specs.BuiltinStrOperationSpecs
 import nuitka.specs.BuiltinUnicodeOperationSpecs
 from nuitka.code_generation.BinaryOperationHelperDefinitions import (
     getSpecializedBinaryOperations,
     parseTypesFromHelper,
 )
+from nuitka.code_generation.c_types.CTypePyObjectPointers import (
+    make_list_constant_direct_threshold,
+    make_list_constant_hinted_threshold,
+)
 from nuitka.code_generation.CallCodes import (
     getQuickCallCode,
     getQuickMethodCallCode,
@@ -52,16 +57,28 @@ from nuitka.nodes.ImportNodes import (
     hard_modules_non_stdlib,
     hard_modules_version,
 )
+from nuitka.nodes.shapes.BuiltinTypeShapes import (
+    tshape_bool,
+    tshape_bytes,
+    tshape_dict,
+    tshape_int,
+    tshape_list,
+    tshape_none,
+    tshape_str,
+    tshape_tuple,
+)
 from nuitka.utils.Jinja2 import getTemplateC
 
 from .Common import (
     formatArgs,
     getMethodVariations,
     python2_dict_methods,
+    python2_list_methods,
     python2_str_methods,
     python2_unicode_methods,
     python3_bytes_methods,
     python3_dict_methods,
+    python3_list_methods,
     python3_str_methods,
     withFileOpenedAndAutoFormatted,
     writeLine,
@@ -713,8 +730,8 @@ def makeHelperImportModuleHard(template, module_name, emit_h, emit_c, emit):
 
 
 def makeHelperCalls():
-    filename_c = "nuitka/build/static_src/HelpersCalling2.c"
-    filename_h = "nuitka/build/include/nuitka/helper/calling2.h"
+    filename_c = "nuitka/build/static_src/HelpersCallingGenerated.c"
+    filename_h = "nuitka/build/include/nuitka/helper/calling_generated.h"
 
     with withFileOpenedAndAutoFormatted(filename_c) as output_c:
         with withFileOpenedAndAutoFormatted(filename_h) as output_h:
@@ -793,6 +810,51 @@ def makeHelperCalls():
                 emit_h(getTemplateCodeDeclaredFunction(code))
 
 
+def makeHelperLists():
+    filename_c = "nuitka/build/static_src/HelpersListsGenerated.c"
+    filename_h = "nuitka/build/include/nuitka/helper/lists_generated.h"
+
+    with withFileOpenedAndAutoFormatted(filename_c) as output_c:
+        with withFileOpenedAndAutoFormatted(filename_h) as output_h:
+
+            def emit_h(*args):
+                assert args[0] != "extern "
+                writeLine(output_h, *args)
+
+            def emit_c(*args):
+                writeLine(output_c, *args)
+
+            def emit(*args):
+                emit_h(*args)
+                emit_c(*args)
+
+            template = getTemplateC(
+                "nuitka.code_generation", "CodeTemplateMakeListSmall.c.j2"
+            )
+
+            emitGenerationWarning(emit, template.name)
+
+            emitIDE(emit)
+
+            for args_count in range(1, make_list_constant_direct_threshold):
+                code = template.render(args_count=args_count)
+
+                emit_c(code)
+                emit_h(getTemplateCodeDeclaredFunction(code))
+
+            template = getTemplateC(
+                "nuitka.code_generation", "CodeTemplateMakeListHinted.c.j2"
+            )
+
+            for args_count in range(
+                make_list_constant_direct_threshold, make_list_constant_hinted_threshold
+            ):
+                code = template.render(args_count=args_count)
+
+                emit_c(code)
+                emit_h(getTemplateCodeDeclaredFunction(code))
+
+
 def _makeHelperBuiltinTypeAttributes(
     type_prefix, type_name, python2_methods, python3_methods, emit_c, emit_h
 ):
@@ -802,7 +864,10 @@ def _makeHelperBuiltinTypeAttributes(
         return "%s_builtin_%s" % (type_prefix, method_name)
 
     for method_name in sorted(set(python2_methods + python3_methods)):
-        is_public = method_name in ("format",)
+        is_public = method_name in (
+            "format",
+            "fromkeys",
+        )
 
         if method_name in python2_methods and method_name not in python3_methods:
             emit_c("#if PYTHON_VERSION < 0x300")
@@ -880,6 +945,16 @@ generate_builtin_type_operations = [
         nuitka.specs.BuiltinDictOperationSpecs,
         ("pop", "popitem", "setdefault"),
     ),
+    (
+        "tshape_list",
+        list_desc,
+        nuitka.specs.BuiltinListOperationSpecs,
+        (
+            "pop",
+            # TODO: template doesn't do positional only yet.
+            # "sort",
+        ),
+    ),
     # TODO: These are very complex things using "string lib" code in CPython,
     # that we do not have easy access to, but we might one day for Nuitka-Python
     # expose it for the static linking of it and then we could in fact call
@@ -973,11 +1048,92 @@ generate_builtin_type_operations = [
         "tshape_bytes",
         bytes_desc,
         nuitka.specs.BuiltinBytesOperationSpecs,
-        ("decode",),
+        (
+            "capitalize",
+            "center",
+            "count",
+            "decode",
+            "endswith",
+            "expandtabs",
+            "find",
+            "index",
+            "isalnum",
+            "isalpha",
+            "isdigit",
+            "islower",
+            "isspace",
+            "istitle",
+            "isupper",
+            "join",
+            "ljust",
+            "lower",
+            "lstrip",
+            "partition",
+            "replace",
+            "rfind",
+            "rindex",
+            "rjust",
+            "rpartition",
+            "rsplit",
+            "rstrip",
+            "split",
+            "splitlines",
+            "startswith",
+            "strip",
+            "swapcase",
+            "title",
+            "translate",
+            "upper",
+            "zfill",
+        ),
     ),
 ]
 
 
+def makeDictCopyHelperCodes():
+    filename_c = "nuitka/build/static_src/HelpersDictionariesGenerated.c"
+
+    with withFileOpenedAndAutoFormatted(filename_c) as output_c:
+
+        def emit(*args):
+            writeLine(output_c, *args)
+
+        emitIDE(emit)
+
+        template = getDoExtensionUsingTemplateC("HelperDictionaryCopy.c.j2")
+
+        emitGenerationWarning(emit, template.name)
+
+        code = template.render()
+
+        emit(code)
+
+
+def _getCheckForShape(shape):
+    # Return driven for better debugging experience, pylint: disable=too-many-return-statements
+
+    if shape is tshape_str:
+        return "Nuitka_String_CheckExact"
+    elif shape is tshape_list:
+        return "PyList_CheckExact"
+    elif shape is tshape_tuple:
+        return "PyTuple_CheckExact"
+    elif shape is tshape_int:
+        # TODO: Not defined a version independent one yet in prelude.h
+        return None
+    elif shape is tshape_bool:
+        return "PyBool_Check"
+    elif shape is tshape_none:
+        # TODO: Not defined one in prelude.h yet
+        return None
+    elif shape is tshape_dict:
+        return "PyDict_CheckExact"
+    elif shape is tshape_bytes:
+        return "PyBytes_CheckExact"
+    else:
+        assert False, shape
+
+
 def makeHelperBuiltinTypeMethods():
     # Many details, pylint: disable=too-many-locals
     filename_c = "nuitka/build/static_src/HelpersBuiltinTypeMethods.c"
@@ -995,8 +1151,14 @@ def makeHelperBuiltinTypeMethods():
                 emit_h(*args)
                 emit_c(*args)
 
+            template = getDoExtensionUsingTemplateC("HelperBuiltinMethodOperation.c.j2")
+
+            emitGenerationWarning(emit, template.name)
+
             emitIDE(emit)
 
+            # TODO: Isn't this creating more than necessary, we don't use all of them, e.g.
+            # not with lists and dicts.
             _makeHelperBuiltinTypeAttributes(
                 "str", "PyString_Type", python2_str_methods, (), emit_c, emit_h
             )
@@ -1019,8 +1181,14 @@ def makeHelperBuiltinTypeMethods():
                 emit_c,
                 emit_h,
             )
-
-            template = getDoExtensionUsingTemplateC("HelperBuiltinMethodOperation.c.j2")
+            _makeHelperBuiltinTypeAttributes(
+                "list",
+                "PyList_Type",
+                python2_list_methods,
+                python3_list_methods,
+                emit_c,
+                emit_h,
+            )
 
             for (
                 shape_name,
@@ -1038,6 +1206,7 @@ def makeHelperBuiltinTypeMethods():
                         _arg_tests,
                         arg_name_mapping,
                         arg_counts,
+                        result_shape,
                     ) = getMethodVariations(
                         spec_module=spec_module,
                         shape_name=shape_name,
@@ -1061,7 +1230,7 @@ def makeHelperBuiltinTypeMethods():
                         if arg_name in arg_name_mapping:
                             arg_name = arg_name_mapping[arg_name]
 
-                        if arg_name in ("default", "new"):
+                        if arg_name in ("default", "new", "delete"):
                             return arg_name + "_value"
                         else:
                             return arg_name
@@ -1083,6 +1252,9 @@ def makeHelperBuiltinTypeMethods():
                             arg_names=variant_args,
                             arg_types=[object_desc] * len(variant_args),
                             formatArgumentDeclaration=formatArgumentDeclaration,
+                            extra_check=_getCheckForShape(result_shape)
+                            if result_shape is not None
+                            else None,
                             zip=zip,
                             len=len,
                             name=template.name,
@@ -1095,16 +1267,19 @@ def makeHelperBuiltinTypeMethods():
 
 
 def main():
+    makeDictCopyHelperCodes()
 
     # Cover many things once first, then cover all for quicker turnaround during development.
-    makeHelperBuiltinTypeMethods()
     makeHelpersComparisonOperation("==", "EQ")
     makeHelpersBinaryOperation("+", "ADD")
     makeHelpersInplaceOperation("+", "ADD")
 
+    makeHelperBuiltinTypeMethods()
+
     makeHelpersImportHard()
 
     makeHelperCalls()
+    makeHelperLists()
 
     makeHelpersBinaryOperation("-", "SUB")
     makeHelpersBinaryOperation("*", "MULT")
